==> chartjs-java-model-1.0.1-sources.jar: software/xdev/chartjs/model/dataset/BigDecimalDataset.java <==
/*
 * Copyright © 2023 XDEV Software (https://xdev.software)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package software.xdev.chartjs.model.dataset;

import java.math.BigDecimal;
import java.util.Arrays;
import java.util.Collection;


public interface BigDecimalDataset<S extends Dataset<?, BigDecimal>>
{
	S self();
	
	default S setData(final int... data)
	{
		this.self().clearData();
		if(data != null)
		{
			Arrays.stream(data).forEach(this::addData);
		}
		return this.self();
	}
	
	default S setData(final double... data)
	{
		this.self().clearData();
		if(data != null)
		{
			Arrays.stream(data).forEach(this::addData);
		}
		return this.self();
	}
	
	/**
	 * Add the data point to this {@code Dataset}
	 *
	 * @see #setData(Collection)
	 */
	default S addData(final int data)
	{
		this.self().addData(BigDecimal.valueOf(data));
		return this.self();
	}
	
	default S addData(final double data)
	{
		this.self().addData(BigDecimal.valueOf(data));
		return this.self();
	}
}

==> chartjs-java-model-1.3.1-sources.jar: software/xdev/chartjs/model/dataset/BigDecimalDataset.java <==
/*
 * Copyright © 2023 XDEV Software (https://xdev.software)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package software.xdev.chartjs.model.dataset;

import java.math.BigDecimal;
import java.util.Arrays;
import java.util.Collection;


public interface BigDecimalDataset<S extends Dataset<?, BigDecimal>>
{
	S self();
	
	default S setData(final int... data)
	{
		this.self().clearData();
		if(data != null)
		{
			Arrays.stream(data).forEach(this::addData);
		}
		return this.self();
	}
	
	default S setData(final double... data)
	{
		this.self().clearData();
		if(data != null)
		{
			Arrays.stream(data).forEach(this::addData);
		}
		return this.self();
	}
	
	/**
	 * Add the data point to this {@code Dataset}
	 *
	 * @see Dataset#setData(Collection)
	 */
	default S addData(final int data)
	{
		this.self().addData(BigDecimal.valueOf(data));
		return this.self();
	}
	
	default S addData(final double data)
	{
		this.self().addData(BigDecimal.valueOf(data));
		return this.self();
	}
}
